@@ -36,7 +36,7 @@ pub struct TcpPort {
 impl TcpPort {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("TCP"));
-        let unit = String::from("");
+        let unit = String::new();
         TcpPort {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
@@ -79,9 +79,9 @@ impl Column for TcpPort {
             ports.sort_unstable();
             ports.dedup();
 
-            format!("{:?}", ports)
+            format!("{ports:?}")
         } else {
-            String::from("")
+            String::new()
         };
         let raw_content = fmt_content.clone();
 
@@ -91,7 +91,7 @@ impl Column for TcpPort {
 
     fn find_exact(&self, pid: i32, keyword: &str, _content_to_lowercase: bool) -> bool {
         if let Some(content) = self.fmt_contents.get(&pid) {
-            let content = content.replace('[', "").replace(']', "");
+            let content = content.replace(['[', ']'], "");
             let content = content.split(',');
             for c in content {
                 if c == keyword {
@@ -121,12 +121,9 @@ impl Column for TcpPort {
     fn add(&mut self, proc: &ProcessInfo) {
         let mut ports = Vec::new();
         for tcp in &proc.curr_tcps {
-            match tcp.tcpsi_state.into() {
-                TcpSIState::Listen => {
-                    let port = crate::util::change_endian(tcp.tcpsi_ini.insi_lport as u32) >> 16;
-                    ports.push(port);
-                }
-                _ => (),
+            if let TcpSIState::Listen = tcp.tcpsi_state.into() {
+                let port = crate::util::change_endian(tcp.tcpsi_ini.insi_lport as u32) >> 16;
+                ports.push(port);
             }
         }
         ports.sort();
@@ -141,7 +138,7 @@ impl Column for TcpPort {
 
     fn find_exact(&self, pid: i32, keyword: &str, _content_to_lowercase: bool) -> bool {
         if let Some(content) = self.fmt_contents.get(&pid) {
-            let content = content.replace("[", "").replace("]", "");
+            let content = content.replace(['[', ']'], "");
             let content = content.split(',');
             for c in content {
                 if c == keyword {
@@ -185,7 +182,7 @@ impl Column for TcpPort {
 
     fn find_exact(&self, pid: i32, keyword: &str, _content_to_lowercase: bool) -> bool {
         if let Some(content) = self.fmt_contents.get(&pid) {
-            let content = content.replace('[', "").replace(']', "");
+            let content = content.replace(['[', ']'], "");
             let content = content.split(',');
             for c in content {
                 if c == keyword {
@@ -330,11 +327,11 @@ mod tests {
             .tcp_entry
             .iter()
             .chain(tcp_port.tcp6_entry.iter())
-            .filter(|entry| {
+            .find(|entry| {
                 entry.state == MIB_TCP_STATE_LISTEN
                     && entry.local_address == listener.local_addr().unwrap()
-            })
-            .next();
+            });
+
         found.is_some()
     }
 }
