@@ -66,3 +66,17 @@ impl Column for VmRss {
 
     column_default!(u64);
 }
+
+#[cfg_attr(tarpaulin, skip)]
+#[cfg(target_os = "freebsd")]
+impl Column for VmRss {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let raw_content = (proc.curr_proc.info.rssize as u64).saturating_mul(4096);
+        let fmt_content = bytify(raw_content);
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(u64);
+}
