@@ -25,6 +25,7 @@ impl Wchan {
     }
 }
 
+#[cfg(any(target_os = "linux", target_os = "android"))]
 impl Column for Wchan {
     fn add(&mut self, proc: &ProcessInfo) {
         let raw_content = proc.curr_proc.wchan().unwrap_or_default();
@@ -40,3 +41,20 @@ impl Column for Wchan {
 
     column_default!(String);
 }
+
+#[cfg(target_os = "freebsd")]
+impl Column for Wchan {
+    fn add(&mut self, proc: &ProcessInfo) {
+        let raw_content = if let Ok(wmesg) = crate::util::i8_to_cstr(&proc.curr_proc.info.wmesg) {
+            wmesg.to_string_lossy().into_owned()
+        } else {
+            String::from("")
+        };
+        let fmt_content = raw_content.clone();
+
+        self.fmt_contents.insert(proc.pid, fmt_content);
+        self.raw_contents.insert(proc.pid, raw_content);
+    }
+
+    column_default!(String);
+}
