@@ -208,12 +208,15 @@ fn get_config(opt: &Opt) -> Result<Config, Error> {
                 .join("config.toml")
         })
         .filter(|path| path.exists());
+    let etc_path = PathBuf::from("/etc/procs/procs.toml");
+    let etc_cfg_path = etc_path.exists().then_some(etc_path);
     let cfg_path = opt
         .load_config
         .clone()
         .or(dot_cfg_path)
         .or(app_cfg_path)
-        .or(xdg_cfg_path);
+        .or(xdg_cfg_path)
+        .or(etc_cfg_path);
 
     let config: Config = if let Some(path) = cfg_path {
         let mut f = fs::File::open(&path).context(format!("failed to open file ({path:?})"))?;
@@ -329,8 +332,6 @@ fn run_list() -> Result<(), Error> {
         width = cmp::max(width, UnicodeWidthStr::width(*v));
     }
 
-    list.sort();
-
     println!("Column kind list:");
     for l in list {
         println!(
