@@ -2,13 +2,16 @@ use crate::column::Column;
 use crate::columns::{ConfigColumnKind, KIND_LIST};
 use crate::config::{Config, ConfigColumnAlign, ConfigSearchCase, ConfigSearchLogic, ConfigTheme};
 use crate::Opt;
-use atty::Stream;
 use byte_unit::Byte;
 use clap::ValueEnum;
+use is_terminal::IsTerminal;
 use std::borrow::Cow;
+use std::io;
 use std::time::Duration;
 use std::time::Instant;
 use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
+#[cfg(not(target_os = "windows"))]
+use uzers::UsersCache;
 
 #[derive(ValueEnum, Copy, Clone, Debug, PartialEq, Eq)]
 pub enum ArgColorMode {
@@ -314,7 +317,8 @@ pub fn get_theme(opt: &Opt, config: &Config) -> ConfigTheme {
     };
     match theme {
         ConfigTheme::Auto => {
-            if atty::is(Stream::Stdout) && atty::is(Stream::Stderr) && atty::is(Stream::Stdin) {
+            if io::stdout().is_terminal() && io::stderr().is_terminal() && io::stdin().is_terminal()
+            {
                 let minimum_timeout = Duration::from_millis(100);
                 let timeout = if let Ok(latency) = termbg::latency(Duration::from_millis(1000)) {
                     if latency * 2 > minimum_timeout {
@@ -344,3 +348,16 @@ pub fn get_theme(opt: &Opt, config: &Config) -> ConfigTheme {
         x => x,
     }
 }
+
+#[cfg(not(target_os = "windows"))]
+thread_local! {
+    pub static USERS_CACHE: std::cell::RefCell<UsersCache> = UsersCache::new().into();
+}
+
+#[cfg(target_os = "freebsd")]
+pub fn i8_to_cstr(x: &[i8]) -> Result<&std::ffi::CStr, std::ffi::FromBytesUntilNulError> {
+    let ptr = x.as_ptr() as *const u8;
+    let len = x.len();
+    let x = unsafe { std::slice::from_raw_parts::<u8>(ptr, len) };
+    std::ffi::CStr::from_bytes_until_nul(x)
+}
